
#include <windows.h>  
#include "GetMChMD.h" 


#if defined (WIN32)
	#define IS_WIN32 TRUE
#else
	#define IS_WIN32 FALSE
#endif

#define IS_NT      IS_WIN32 && (BOOL)(GetVersion() < 0x80000000)
#define IS_WIN32S  IS_WIN32 && (BOOL)(!(IS_NT) && (LOBYTE(LOWORD(GetVersion()))<4))
#define IS_WIN95   (BOOL)(!(IS_NT) && !(IS_WIN32S)) && IS_WIN32

HINSTANCE hInst;   // current instance

LPCTSTR lpszAppName  = "MyApp";
LPCTSTR lpszTitle    = "My Application"; 

BOOL RegisterWin95( CONST WNDCLASS* lpwc );

int APIENTRY WinMain( HINSTANCE hInstance, HINSTANCE hPrevInstance,
                      LPTSTR lpCmdLine, int nCmdShow)
{
   MSG      msg;
   HWND     hWnd; 
   WNDCLASS wc;

   // Register the main application window class.
   //............................................
   wc.style         = CS_HREDRAW | CS_VREDRAW;
   wc.lpfnWndProc   = (WNDPROC)WndProc;       
   wc.cbClsExtra    = 0;                      
   wc.cbWndExtra    = 0;                      
   wc.hInstance     = hInstance;              
   wc.hIcon         = LoadIcon( hInstance, lpszAppName ); 
   wc.hCursor       = LoadCursor(NULL, IDC_ARROW);
   wc.hbrBackground = (HBRUSH)(COLOR_WINDOW+1);
   wc.lpszMenuName  = lpszAppName;              
   wc.lpszClassName = lpszAppName;              

   if ( IS_WIN95 )
   {
      if ( !RegisterWin95( &wc ) )
         return( FALSE );
   }
   else if ( !RegisterClass( &wc ) )
      return( FALSE );

   hInst = hInstance; 

   // Create the main application window.
   //....................................
   hWnd = CreateWindow( lpszAppName, 
                        lpszTitle,    
                        WS_OVERLAPPEDWINDOW, 
                        CW_USEDEFAULT, 0, 
                        CW_USEDEFAULT, 0,  
                        NULL,              
                        NULL,              
                        hInstance,         
                        NULL               
                      );

   if ( !hWnd ) 
      return( FALSE );

   ShowWindow( hWnd, nCmdShow ); 
   UpdateWindow( hWnd );         

   while( GetMessage( &msg, NULL, 0, 0) )   
   {
      TranslateMessage( &msg ); 
      DispatchMessage( &msg );  
   }

   return( msg.wParam ); 
}


BOOL RegisterWin95( CONST WNDCLASS* lpwc )
{
   WNDCLASSEX wcex;

   wcex.style         = lpwc->style;
   wcex.lpfnWndProc   = lpwc->lpfnWndProc;
   wcex.cbClsExtra    = lpwc->cbClsExtra;
   wcex.cbWndExtra    = lpwc->cbWndExtra;
   wcex.hInstance     = lpwc->hInstance;
   wcex.hIcon         = lpwc->hIcon;
   wcex.hCursor       = lpwc->hCursor;
   wcex.hbrBackground = lpwc->hbrBackground;
   wcex.lpszMenuName  = lpwc->lpszMenuName;
   wcex.lpszClassName = lpwc->lpszClassName;

   // Added elements for Windows 95.
   //...............................
   wcex.cbSize = sizeof(WNDCLASSEX);
   wcex.hIconSm = LoadImage(wcex.hInstance, lpwc->lpszClassName, 
                            IMAGE_ICON, 16, 16,
                            LR_DEFAULTCOLOR );
			
   return RegisterClassEx( &wcex );
}

LRESULT CALLBACK WndProc( HWND hWnd, UINT uMsg, WPARAM wParam, LPARAM lParam )
{
static HBITMAP hMemBitmap;

   switch( uMsg )
   {
      case WM_CREATE :
            {
               HDC     hSrcDC, hDstDC;
               BITMAP  bm;
               HBITMAP hChkBitmap;

               HMENU hMenu      = GetMenu( hWnd );
               LONG  lCheckSize = GetMenuCheckMarkDimensions();
               SHORT nBx        = LOWORD( lCheckSize );
               SHORT nBy        = HIWORD( lCheckSize );
               HDC   hDC        = GetDC( hWnd );
               
               // Create a memory DC to select the bitmap into.
               //..............................................
               hSrcDC = CreateCompatibleDC( hDC );
               hChkBitmap = LoadBitmap( hInst, "Checkmark" );

               SelectObject( hSrcDC, hChkBitmap );

               GetObject( hChkBitmap, sizeof( BITMAP), &bm );

               // Create a memory DC to stretch the bitmap into.
               //...............................................
               hDstDC     = CreateCompatibleDC( hDC );
               hMemBitmap = CreateCompatibleBitmap( hDstDC, nBx, nBy );
               SelectObject( hDstDC, hMemBitmap );

               StretchBlt( hDstDC, 0, 0, nBx, nBy, hSrcDC, 0, 0,
                           bm.bmWidth, bm.bmHeight, SRCCOPY );

               // Set the bitmap to use for checking to the newly sized
               // bitmap.
               //......................................................
               SetMenuItemBitmaps( hMenu, IDM_CHKITEM, MF_BYCOMMAND, NULL,
                                   hMemBitmap );

               DeleteDC( hSrcDC );
               DeleteDC( hDstDC );
               ReleaseDC( hWnd, hDC );
               DeleteObject( hChkBitmap );
            }
            break;

      case WM_COMMAND :
              switch( LOWORD( wParam ) )
              {
                 case IDM_CHKITEM :
                      { 
                         HMENU hMenu  = GetMenu( hWnd );
                         UINT  uState = GetMenuState( hMenu,
                                                      IDM_CHKITEM,
                                                      MF_BYCOMMAND );

                         if ( uState & MFS_CHECKED )
                            CheckMenuItem( hMenu, IDM_CHKITEM, 
                                           MF_BYCOMMAND | MFS_UNCHECKED );
                         else
                            CheckMenuItem( hMenu, IDM_CHKITEM,
                                           MF_BYCOMMAND | MFS_CHECKED );
                      }
                      break;

                 case IDM_ABOUT :
                        DialogBox( hInst, "AboutBox", hWnd, (DLGPROC)About );
                        break;

                 case IDM_EXIT :
                        DestroyWindow( hWnd );
                        break;
              }
              break;
      
      case WM_DESTROY :
              DeleteObject( hMemBitmap );
              PostQuitMessage(0);
              break;

      default :
            return( DefWindowProc( hWnd, uMsg, wParam, lParam ) );
   }

   return( 0L );
}


LRESULT CALLBACK About( HWND hDlg,           
                        UINT message,        
                        WPARAM wParam,       
                        LPARAM lParam)
{
   switch (message) 
   {
       case WM_INITDIALOG: 
               return (TRUE);

       case WM_COMMAND:                              
               if (   LOWORD(wParam) == IDOK         
                   || LOWORD(wParam) == IDCANCEL)    
               {
                       EndDialog(hDlg, TRUE);        
                       return (TRUE);
               }
               break;
   }

   return (FALSE); 
}
